<?php
/*
 +-------------------------------------------------------------------------+
 | Copyright (C) 2004-2009 The Cacti Group                                 |
 |                                                                         |
 | This program is free software; you can redistribute it and/or           |
 | modify it under the terms of the GNU General Public License             |
 | as published by the Free Software Foundation; either version 2          |
 | of the License, or (at your option) any later version.                  |
 |                                                                         |
 | This program is distributed in the hope that it will be useful,         |
 | but WITHOUT ANY WARRANTY; without even the implied warranty of          |
 | MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the           |
 | GNU General Public License for more details.                            |
 +-------------------------------------------------------------------------+
 | Cacti: The Complete RRDTool-based Graphing Solution                     |
 +-------------------------------------------------------------------------+
 | This code is designed, written, and maintained by the Cacti Group. See  |
 | about.php and/or the AUTHORS file for specific developer information.   |
 +-------------------------------------------------------------------------+
 | http://www.cacti.net/                                                   |
 +-------------------------------------------------------------------------+
*/
/*******************************************************************************

    Author ......... Matej Vadnjal
    Contact ........ matej@vadnjal.net
    Home Site ...... http://forums.cacti.net/
    Program ........ Format Title "plugin formattitle"
    Purpose ........ Change the look of Cacti page titles
*******************************************************************************/
define("formattitleVERSIONPLUGIN", "0.1");

function plugin_init_formattitle() {
	global $plugin_hooks;

}

/* plugin install - provides a generic PIA 2.x installer routine to register all plugin hook functions.
*/
function plugin_formattitle_install() {
	api_plugin_register_hook('formattitle', 'page_title',      'formattitle_format_title',   "setup.php");
	api_plugin_register_hook('formattitle', 'config_settings', 'formattitle_config_settings', "setup.php");

   formattitle_setup_table_new ();
}

/* plugin uninstall - a generic uninstall routine.  Right now it will do nothing as I
   If you don't want the tables removed from the system except let it empty. */
function plugin_formattitle_uninstall () {
	/* Do any extra Uninstall stuff here */
}

function plugin_formattitle_check_config () {
	/* Here we will check to ensure everything is configured */
	return true;
}

function plugin_formattitle_upgrade () {
	/* Here we will upgrade to the newest version */
	formattitle_check_upgrade();
	return false;
}

function plugin_formattitle_version () {
	return formattitle_version();
}

function formattitle_check_upgrade () {
	global $config;

	$files = array('index.php', 'plugins.php');
	if (isset($_SERVER['PHP_SELF']) && !in_array(basename($_SERVER['PHP_SELF']), $files)) {
		return;
	}

	$current = plugin_formattitle_version();
	$current = $current['version'];
	$old     = db_fetch_row("SELECT * FROM plugin_config WHERE directory='formattitle'");
	if (sizeof($old) && $current != $old["version"]) {
		/* if the plugin is installed and/or active */
		if ($old["status"] == 1 || $old["status"] == 4) {
			/* re-register the hooks */
			plugin_formattitle_install();

			/* perform a database upgrade */
			formattitle_database_upgrade();
		}

		/* update the plugin information */
		$info = plugin_formattitle_version();
		$id   = db_fetch_cell("SELECT id FROM plugin_config WHERE directory='formattitle'");
		db_execute("UPDATE plugin_config
			SET name='" . $info["longname"] . "',
			author='"   . $info["author"]   . "',
			webpage='"  . $info["homepage"] . "',
			version='"  . $info["version"]  . "'
			WHERE id='$id'");
	}
}

function formattitle_database_upgrade () {
}

function formattitle_check_dependencies() {
	global $plugins, $config;

	return true;
}

function formattitle_setup_table_new () {
}

function formattitle_version () {
    return array( 
            'name'     => 'Format Title',
            'version'  => formattitleVERSIONPLUGIN,
            'longname' => 'Format Cacti Page Titles',
            'author'   => 'Matej Vadnjal',
            'homepage' => 'http://forums.cacti.net/',
            'email'    => 'matej@vadnjal.net',
            'url'      => 'http://forums.cacti.net/'
            );
}

function formattitle_config_settings () {
	global $tabs, $settings;

	/* check for an upgrade */
	plugin_formattitle_check_config();

	if (isset($_SERVER['PHP_SELF']) && basename($_SERVER['PHP_SELF']) != 'settings.php')
		return;

	$tabs["misc"] = "Misc";

	$temp = array(
		"formattitle_header" => array(
			"friendly_name" => "Format Page Title",
			"method" => "spacer",
			),
		"formattitle_reverse" => array(
			"friendly_name" => "Reverse Title",
			"description" => "Reverse breadcrumbs of navigation text (more specific to less specific). Useful when using a large number of browser tabs.",
			"method" => "checkbox",
			),
		"formattitle_separator" => array(
			"friendly_name" => "Hierarchy Separator",
			"description" => "Text to use between breadcrumbs of navigation text. Defaults to ' -> '",
			"method" => "textbox",
			"max_length" => 10,
			),
	);
	if (isset($settings["misc"]))
		$settings["misc"] = array_merge($settings["misc"], $temp);
	else
		$settings["misc"]=$temp;
}





/*
 * Do the actual title formatting.
 */
function formattitle_format_title($title_text) {

	$reverse    = read_config_option("formattitle_reverse");
	$separator  = read_config_option("formattitle_separator");

	$default_separator = " -> ";

	if ( !$reverse && (!$separator || $separator == $default_separator) ) {
		return $title_text;
	}

	$separator = ($separator) ? $separator : $default_separator;
	$nav_parts = explode($default_separator, $title_text);

	if ($reverse)
		$nav_parts = array_reverse($nav_parts);

	$new_title = implode($separator, $nav_parts);

	return $new_title;
}

?>
